@@ -15,7 +15,7 @@ Astro::Constants - this library provides physical constants for use in Astronomy
 
 =head1 VERSION
 
-version 0.09_91
+version 0.09_92
 
 =head1 SYNOPSIS
 
@@ -43,10 +43,13 @@ library and are available through the import tag C<:short>.
 The values are stored in F<Physical_Constants.xml> in the B<data> directory
 and are mostly based on the 2014 CODATA values from NIST.
 
-The problem with long constants is that they are not interpolated
-in double quotish situations because they are really inlined functions.
-The problem with short name constants is that they use L<Scalar::Constant>
-instead of L<constant> and are 33% slower.
+Long name constants are constructed with the L<constant> pragma and
+are not interpolated in double quotish situations because they are 
+really inlined functions.
+Short name constants are constructed with the age-old idiom of fiddling
+with the symbol table using typeglobs, e.g. C<*PI = \3.14159>,
+and may be slower than the long name constants.
+I<This could do with some benchmarking.>
 
 =head2 Why use this module
 
@@ -63,8 +66,9 @@ Your programming errors are a little easier to find when you can see that the un
 don't match.  Isn't it reassuring that you can verify how a number is produced
 and which meeting of which standards body is responsible for its value?
 
-Trusting someone else's code does carry some risk, which you _should_ consider, 
-but have you also considered the risk of doing it yourself with no one to check your work?
+Trusting someone else's code does carry some risk, which you I<should> consider, 
+but have you also considered the risk of doing it yourself with no one else 
+to check your work?
 
 =head1 METHODS
 
@@ -75,7 +79,7 @@ but have you also considered the risk of doing it yourself with no one to check
 
 speed of light in a vacuum
 
-This constant can also be accessed through the short name $A_c (deprecated)
+This constant can also be accessed through the variable $A_c (which may be deprecated)
 
 =head2 BOLTZMANN
 
@@ -84,7 +88,7 @@ This constant can also be accessed through the short name $A_c (deprecated)
 
 Boltzmann's constant
 
-This constant can also be accessed through the short name $A_k (deprecated)
+This constant can also be accessed through the variable $A_k (which may be deprecated)
 
 =head2 GRAVITATIONAL
 
@@ -93,7 +97,7 @@ This constant can also be accessed through the short name $A_k (deprecated)
 
 universal gravitational constant
 
-This constant can also be accessed through the short name $A_G (deprecated)
+This constant can also be accessed through the variable $A_G (which may be deprecated)
 
 =head2 ELECTRON_VOLT
 
@@ -102,7 +106,7 @@ This constant can also be accessed through the short name $A_G (deprecated)
 
 electron volt
 
-This constant can also be accessed through the short name $A_eV (deprecated)
+This constant can also be accessed through the variable $A_eV (which may be deprecated)
 
 =head2 PLANCK
 
@@ -111,7 +115,7 @@ This constant can also be accessed through the short name $A_eV (deprecated)
 
 Planck constant
 
-This constant can also be accessed through the short name $A_h (deprecated)
+This constant can also be accessed through the variable $A_h (which may be deprecated)
 
 =head2 HBAR
 
@@ -120,7 +124,7 @@ This constant can also be accessed through the short name $A_h (deprecated)
 
 Planck's constant /2pi
 
-This constant can also be accessed through the short name $A_hbar (deprecated)
+This constant can also be accessed through the variable $A_hbar (which may be deprecated)
 
 =head2 ELECTRON_CHARGE
 
@@ -129,7 +133,7 @@ This constant can also be accessed through the short name $A_hbar (deprecated)
 
 electron charge (defined positive)
 
-This constant can also be accessed through the short name $A_e (deprecated)
+This constant can also be accessed through the variable $A_e (which may be deprecated)
 
 =head2 STEFAN_BOLTZMANN
 
@@ -138,7 +142,7 @@ This constant can also be accessed through the short name $A_e (deprecated)
 
 Stefan-Boltzmann constant
 
-This constant can also be accessed through the short name $A_sigma (deprecated)
+This constant can also be accessed through the variable $A_sigma (which may be deprecated)
 
 =head2 A_RAD
 
@@ -147,7 +151,7 @@ This constant can also be accessed through the short name $A_sigma (deprecated)
 
 radiation density constant, 4 * sigma / c
 
-This constant can also be accessed through the short name $A_arad (deprecated)
+This constant can also be accessed through the variable $A_arad (which may be deprecated)
 
 =head2 WIEN
 
@@ -156,7 +160,7 @@ This constant can also be accessed through the short name $A_arad (deprecated)
 
 Wien wavelength displacement law constant
 
-This constant can also be accessed through the short name $A_Wien (deprecated)
+This constant can also be accessed through the variable $A_Wien (which may be deprecated)
 
 =head2 ALPHA
 
@@ -165,7 +169,7 @@ This constant can also be accessed through the short name $A_Wien (deprecated)
 
 fine structure constant
 
-This constant can also be accessed through the short name $A_alpha (deprecated)
+This constant can also be accessed through the variable $A_alpha (which may be deprecated)
 
 =head2 VACUUM_IMPEDANCE
 
@@ -173,7 +177,7 @@ This constant can also be accessed through the short name $A_alpha (deprecated)
 
 characteristic impedance of vacuum
 
-This constant can also be accessed through the short name $A_Z0 (deprecated)
+This constant can also be accessed through the variable $A_Z0 (which may be deprecated)
 
 =head2 PERMITIV_FREE_SPACE
 
@@ -182,7 +186,7 @@ This constant can also be accessed through the short name $A_Z0 (deprecated)
 
 permittivity of free space, epsilon_0, the electric constant
 
-This constant can also be accessed through the short name $A_eps0 (deprecated)
+This constant can also be accessed through the variable $A_eps0 (which may be deprecated)
 
 =head2 PERMEABL_FREE_SPACE
 
@@ -191,7 +195,7 @@ This constant can also be accessed through the short name $A_eps0 (deprecated)
 
 permeability of free space, mu_0, the magnetic constant
 
-This constant can also be accessed through the short name $A_mu0 (deprecated)
+This constant can also be accessed through the variable $A_mu0 (which may be deprecated)
 
 =head2 PI
 
@@ -199,7 +203,7 @@ This constant can also be accessed through the short name $A_mu0 (deprecated)
 
 trig constant pi
 
-This constant can also be accessed through the short name $A_pi (deprecated)
+This constant can also be accessed through the variable $A_pi (which may be deprecated)
 
 =head2 EXP
 
@@ -207,7 +211,7 @@ This constant can also be accessed through the short name $A_pi (deprecated)
 
 base of natural logarithm
 
-This constant can also be accessed through the short name $A_exp (deprecated)
+This constant can also be accessed through the variable $A_exp (which may be deprecated)
 
 =head2 ATOMIC_MASS_UNIT
 
@@ -216,7 +220,7 @@ This constant can also be accessed through the short name $A_exp (deprecated)
 
 atomic mass unit, 1 u
 
-This constant can also be accessed through the short name $A_amu (deprecated)
+This constant can also be accessed through the variable $A_amu (which may be deprecated)
 
 =head2 PARSEC
 
@@ -225,7 +229,7 @@ This constant can also be accessed through the short name $A_amu (deprecated)
 
 parsec
 
-This constant can also be accessed through the short name $A_pc (deprecated)
+This constant can also be accessed through the variable $A_pc (which may be deprecated)
 
 =head2 ASTRONOMICAL_UNIT
 
@@ -234,7 +238,7 @@ This constant can also be accessed through the short name $A_pc (deprecated)
 
 astronomical unit
 
-This constant can also be accessed through the short name $A_AU (deprecated)
+This constant can also be accessed through the variable $A_AU (which may be deprecated)
 
 =head2 LIGHT_YEAR
 
@@ -243,7 +247,7 @@ This constant can also be accessed through the short name $A_AU (deprecated)
 
 the distance that light travels in vacuum in one Julian year
 
-This constant can also be accessed through the short name $A_ly (deprecated)
+This constant can also be accessed through the variable $A_ly (which may be deprecated)
 
 =head2 ANGSTROM
 
@@ -252,7 +256,7 @@ This constant can also be accessed through the short name $A_ly (deprecated)
 
 Angstrom
 
-This constant can also be accessed through the short name $A_AA (deprecated)
+This constant can also be accessed through the variable $A_AA (which may be deprecated)
 
 =head2 JANSKY
 
@@ -261,7 +265,7 @@ This constant can also be accessed through the short name $A_AA (deprecated)
 
 Jansky
 
-This constant can also be accessed through the short name $A_Jy (deprecated)
+This constant can also be accessed through the variable $A_Jy (which may be deprecated)
 
 =head2 AVOGADRO
 
@@ -269,7 +273,7 @@ This constant can also be accessed through the short name $A_Jy (deprecated)
 
 Avogadro's number
 
-This constant can also be accessed through the short name $A_NA (deprecated)
+This constant can also be accessed through the variable $A_NA (which may be deprecated)
 
 =head2 YEAR
 
@@ -277,7 +281,7 @@ This constant can also be accessed through the short name $A_NA (deprecated)
 
 defined as exactly 365.25 days of 86400 SI seconds
 
-This constant can also be accessed through the short name $A_yr (deprecated)
+This constant can also be accessed through the variable $A_yr (which may be deprecated)
 
 =head2 YEAR_TROPICAL
 
@@ -310,7 +314,7 @@ the period between successive passages of the Sun (as seen from the geocenter) t
 
 solar mass
 
-This constant can also be accessed through the short name $A_msun (deprecated)
+This constant can also be accessed through the variable $A_msun (which may be deprecated)
 
 =head2 SOLAR_LUMINOSITY
 
@@ -319,7 +323,7 @@ This constant can also be accessed through the short name $A_msun (deprecated)
 
 solar luminosity
 
-This constant can also be accessed through the short name $A_Lsun (deprecated)
+This constant can also be accessed through the variable $A_Lsun (which may be deprecated)
 
 =head2 RHO_C
 
@@ -328,7 +332,7 @@ This constant can also be accessed through the short name $A_Lsun (deprecated)
 
 critical density /h^2
 
-This constant can also be accessed through the short name $A_rhoc (deprecated)
+This constant can also be accessed through the variable $A_rhoc (which may be deprecated)
 
 =head2 HUBBLE_TIME
 
@@ -336,7 +340,7 @@ This constant can also be accessed through the short name $A_rhoc (deprecated)
 
 Hubble time *h, the inverse of Hubble's constant valued at 100 km/s/Mpc (DEPRECATED - see ChangeLog)
 
-This constant can also be accessed through the short name $A_tH (deprecated)
+This constant can also be accessed through the variable $A_tH (which may be deprecated)
 
 =head2 CMB_TEMPERATURE
 
@@ -344,7 +348,7 @@ This constant can also be accessed through the short name $A_tH (deprecated)
 
 cosmic microwave background temperature
 
-This constant can also be accessed through the short name $A_TCMB (deprecated)
+This constant can also be accessed through the variable $A_TCMB (which may be deprecated)
 
 =head2 SOLAR_V_MAG
 
@@ -352,7 +356,7 @@ This constant can also be accessed through the short name $A_TCMB (deprecated)
 
 solar V magnitude
 
-This constant can also be accessed through the short name $A_Vsun (deprecated)
+This constant can also be accessed through the variable $A_Vsun (which may be deprecated)
 
 =head2 SOLAR_V_ABS_MAG
 
@@ -360,7 +364,7 @@ This constant can also be accessed through the short name $A_Vsun (deprecated)
 
 solar absolute V magnitude
 
-This constant can also be accessed through the short name $A_MVsun (deprecated)
+This constant can also be accessed through the variable $A_MVsun (which may be deprecated)
 
 =head2 SOLAR_RADIUS
 
@@ -369,7 +373,7 @@ This constant can also be accessed through the short name $A_MVsun (deprecated)
 
 solar radius
 
-This constant can also be accessed through the short name $A_rsun (deprecated)
+This constant can also be accessed through the variable $A_rsun (which may be deprecated)
 
 =head2 EARTH_MASS
 
@@ -378,7 +382,7 @@ This constant can also be accessed through the short name $A_rsun (deprecated)
 
 mass of Earth
 
-This constant can also be accessed through the short name $A_mearth (deprecated)
+This constant can also be accessed through the variable $A_mearth (which may be deprecated)
 
 =head2 EARTH_RADIUS
 
@@ -387,7 +391,7 @@ This constant can also be accessed through the short name $A_mearth (deprecated)
 
 radius of Earth
 
-This constant can also be accessed through the short name $A_rearth (deprecated)
+This constant can also be accessed through the variable $A_rearth (which may be deprecated)
 
 =head2 SOLAR_TEMPERATURE
 
@@ -395,7 +399,7 @@ This constant can also be accessed through the short name $A_rearth (deprecated)
 
 surface temperature of sun
 
-This constant can also be accessed through the short name $A_Tsun (deprecated)
+This constant can also be accessed through the variable $A_Tsun (which may be deprecated)
 
 =head2 SOLAR_DENSITY
 
@@ -404,7 +408,7 @@ This constant can also be accessed through the short name $A_Tsun (deprecated)
 
 mean solar density
 
-This constant can also be accessed through the short name $A_dsun (deprecated)
+This constant can also be accessed through the variable $A_dsun (which may be deprecated)
 
 =head2 EARTH_DENSITY
 
@@ -413,7 +417,7 @@ This constant can also be accessed through the short name $A_dsun (deprecated)
 
 mean Earth density
 
-This constant can also be accessed through the short name $A_dearth (deprecated)
+This constant can also be accessed through the variable $A_dearth (which may be deprecated)
 
 =head2 SOLAR_GRAVITY
 
@@ -422,7 +426,7 @@ This constant can also be accessed through the short name $A_dearth (deprecated)
 
 solar surface gravity
 
-This constant can also be accessed through the short name $A_gsun (deprecated)
+This constant can also be accessed through the variable $A_gsun (which may be deprecated)
 
 =head2 EARTH_GRAVITY
 
@@ -431,7 +435,7 @@ This constant can also be accessed through the short name $A_gsun (deprecated)
 
 Earth surface gravity
 
-This constant can also be accessed through the short name $A_gearth (deprecated)
+This constant can also be accessed through the variable $A_gearth (which may be deprecated)
 
 =head2 LUNAR_RADIUS
 
@@ -440,7 +444,7 @@ This constant can also be accessed through the short name $A_gearth (deprecated)
 
 lunar radius
 
-This constant can also be accessed through the short name $A_rmoon (deprecated)
+This constant can also be accessed through the variable $A_rmoon (which may be deprecated)
 
 =head2 LUNAR_MASS
 
@@ -449,7 +453,7 @@ This constant can also be accessed through the short name $A_rmoon (deprecated)
 
 lunar mass
 
-This constant can also be accessed through the short name $A_mmoon (deprecated)
+This constant can also be accessed through the variable $A_mmoon (which may be deprecated)
 
 =head2 LUNAR_SM_AXIS
 
@@ -458,7 +462,7 @@ This constant can also be accessed through the short name $A_mmoon (deprecated)
 
 lunar orbital semi-major axis
 
-This constant can also be accessed through the short name $A_amoon (deprecated)
+This constant can also be accessed through the variable $A_amoon (which may be deprecated)
 
 =head2 LUNAR_ECCENTRICITY
 
@@ -466,7 +470,7 @@ This constant can also be accessed through the short name $A_amoon (deprecated)
 
 lunar orbital eccentricity
 
-This constant can also be accessed through the short name $A_emoon (deprecated)
+This constant can also be accessed through the variable $A_emoon (which may be deprecated)
 
 =head2 THOMSON_XSECTION
 
@@ -475,7 +479,7 @@ This constant can also be accessed through the short name $A_emoon (deprecated)
 
 Thomson cross-section
 
-This constant can also be accessed through the short name $A_sigmaT (deprecated)
+This constant can also be accessed through the variable $A_sigmaT (which may be deprecated)
 
 =head2 ELECTRON_MASS
 
@@ -484,7 +488,7 @@ This constant can also be accessed through the short name $A_sigmaT (deprecated)
 
 mass of electron
 
-This constant can also be accessed through the short name $A_me (deprecated)
+This constant can also be accessed through the variable $A_me (which may be deprecated)
 
 =head2 PROTON_MASS
 
@@ -493,7 +497,7 @@ This constant can also be accessed through the short name $A_me (deprecated)
 
 mass of proton
 
-This constant can also be accessed through the short name $A_mp (deprecated)
+This constant can also be accessed through the variable $A_mp (which may be deprecated)
 
 =head2 NEUTRON_MASS
 
@@ -502,7 +506,7 @@ This constant can also be accessed through the short name $A_mp (deprecated)
 
 neutron mass
 
-This constant can also be accessed through the short name $A_mn (deprecated)
+This constant can also be accessed through the variable $A_mn (which may be deprecated)
 
 =head2 HYDROGEN_MASS
 
@@ -510,7 +514,7 @@ This constant can also be accessed through the short name $A_mn (deprecated)
 
 mass of Hydrogen atom
 
-This constant can also be accessed through the short name $A_mH (deprecated)
+This constant can also be accessed through the variable $A_mH (which may be deprecated)
 
 =head2 MASS_ALPHA
 
@@ -518,7 +522,7 @@ This constant can also be accessed through the short name $A_mH (deprecated)
 
 mass of alpha particle
 
-This constant can also be accessed through the short name $A_ma (deprecated)
+This constant can also be accessed through the variable $A_ma (which may be deprecated)
 
 =head2 ELECTRON_RADIUS
 
@@ -527,7 +531,7 @@ This constant can also be accessed through the short name $A_ma (deprecated)
 
 classical electron radius
 
-This constant can also be accessed through the short name $A_re (deprecated)
+This constant can also be accessed through the variable $A_re (which may be deprecated)
 
 =head2 BOHR_RADIUS
 
@@ -536,7 +540,7 @@ This constant can also be accessed through the short name $A_re (deprecated)
 
 Bohr radius
 
-This constant can also be accessed through the short name $A_a0 (deprecated)
+This constant can also be accessed through the variable $A_a0 (which may be deprecated)
 
 =head1 EXPORT
 
@@ -626,11 +630,21 @@ Reference Documents:
 
 =head1 ISSUES
 
-File issues at the Github repository L<https://github.com/duffee/Astro-Constants/>
+File issues/suggestions at the Github repository L<https://github.com/duffee/Astro-Constants/>.
+The venerable L<https://rt.cpan.org/Dist/Display.html?Status=Active&Queue=Astro-Constants|RT>
+is the canonical bug tracker that is clocked by L<https://metacpan.org/pod/Astro::Constants|meta::cpan>.
 
 Using C<strict> is a must with this code.  Any constants you forgot to import will
 evaluate to 0 and silently introduce errors in your code.  Caveat Programmer.
 
+If you are using this module, drop me a line using any available means at your 
+disposal, including
+*gasp* email (address in the Author section), to let me know how you're using it. 
+What new features would you like to see?
+If you've had an experience with using the module, let other people know what you
+think, good or bad, by rating it at
+L<http://cpanratings.perl.org/rate/?distribution=Astro-Constants|cpanratings>.
+
 =head2 Extending the data set
 
 If you want to add in your own constants or override the factory defaults,
